# This file was autogenerated from vk-api json schema

from typing import List, Union, Optional, overload
from easy_vk.types import objects
from easy_vk.types import responses
from easy_vk.api_category import BaseCategory
try:
    from typing import Literal
except Exception:
    from typing_extensions import Literal


class Friends(BaseCategory):
    def __init__(self, session, access_token: str, v: str, last_call_timer, delay: float, auto_retry: bool, max_retries: int, timeout: float):
        super().__init__(session, access_token, v, last_call_timer, delay, auto_retry, max_retries, timeout)

    def add(self, user_id: Optional[int] = None, text: Optional[str] = None, follow: Optional[bool] = None) -> responses.FriendsAdd:
        """
        Approves or creates a friend request.
        
        :param user_id: ID of the user whose friend request will be approved or to whom a friend request will be sent.
        :param text: Text of the message (up to 500 characters) for the friend request, if any.
        :param follow: '1' to pass an incoming request to followers list.
        """
    
        method_parameters = {k: v for k, v in locals().items() if k not in {'self', 'raw_response'}}
        param_aliases = []
        method_name = 'friends.add'
        response_type = responses.FriendsAdd
        return self._call(method_name, method_parameters, param_aliases, response_type)

    def add_list(self, name: str, user_ids: Optional[List[int]] = None) -> responses.FriendsAddList:
        """
        Creates a new friend list for the current user.
        
        :param name: Name of the friend list.
        :param user_ids: IDs of users to be added to the friend list.
        """
    
        method_parameters = {k: v for k, v in locals().items() if k not in {'self', 'raw_response'}}
        param_aliases = []
        method_name = 'friends.addList'
        response_type = responses.FriendsAddList
        return self._call(method_name, method_parameters, param_aliases, response_type)

    @overload
    def are_friends(self, user_ids: List[int], need_sign: Optional[bool] = None, extended: None = None) -> responses.FriendsAreFriends: ...
    @overload
    def are_friends(self, user_ids: List[int], extended: bool, need_sign: Optional[bool] = None) -> responses.FriendsAreFriendsExtended: ...
    def are_friends(self, user_ids: List[int], need_sign: Optional[bool] = None, extended: Optional[bool] = None):
        """
        Checks the current user's friendship status with other specified users.
        
        :param user_ids: IDs of the users whose friendship status to check.
        :param need_sign: '1' — to return 'sign' field. 'sign' is md5("{id}_{user_id}_{friends_status}_{application_secret}"), where id is current user ID. This field allows to check that data has not been modified by the client. By default: '0'.
        :param extended: Return friend request read_state field
        """
    
        method_parameters = {k: v for k, v in locals().items() if k not in {'self', 'raw_response'}}
        param_aliases = []
        method_name = 'friends.areFriends'
        if not extended:
            response_type = responses.FriendsAreFriends
        if extended:
            response_type = responses.FriendsAreFriendsExtended
        return self._call(method_name, method_parameters, param_aliases, response_type)

    def delete(self, user_id: Optional[int] = None) -> responses.FriendsDelete:
        """
        Declines a friend request or deletes a user from the current user's friend list.
        
        :param user_id: ID of the user whose friend request is to be declined or who is to be deleted from the current user's friend list.
        """
    
        method_parameters = {k: v for k, v in locals().items() if k not in {'self', 'raw_response'}}
        param_aliases = []
        method_name = 'friends.delete'
        response_type = responses.FriendsDelete
        return self._call(method_name, method_parameters, param_aliases, response_type)

    def delete_all_requests(self) -> responses.BaseOk:
        """
        Marks all incoming friend requests as viewed.
        """
    
        method_parameters = {k: v for k, v in locals().items() if k not in {'self', 'raw_response'}}
        param_aliases = []
        method_name = 'friends.deleteAllRequests'
        response_type = responses.BaseOk
        return self._call(method_name, method_parameters, param_aliases, response_type)

    def delete_list(self, list_id: int) -> responses.BaseOk:
        """
        Deletes a friend list of the current user.
        
        :param list_id: ID of the friend list to delete.
        """
    
        method_parameters = {k: v for k, v in locals().items() if k not in {'self', 'raw_response'}}
        param_aliases = []
        method_name = 'friends.deleteList'
        response_type = responses.BaseOk
        return self._call(method_name, method_parameters, param_aliases, response_type)

    def edit(self, user_id: int, list_ids: Optional[List[int]] = None) -> responses.BaseOk:
        """
        Edits the friend lists of the selected user.
        
        :param user_id: ID of the user whose friend list is to be edited.
        :param list_ids: IDs of the friend lists to which to add the user.
        """
    
        method_parameters = {k: v for k, v in locals().items() if k not in {'self', 'raw_response'}}
        param_aliases = []
        method_name = 'friends.edit'
        response_type = responses.BaseOk
        return self._call(method_name, method_parameters, param_aliases, response_type)

    def edit_list(self, list_id: int, name: Optional[str] = None, user_ids: Optional[List[int]] = None, add_user_ids: Optional[List[int]] = None, delete_user_ids: Optional[List[int]] = None) -> responses.BaseOk:
        """
        Edits a friend list of the current user.
        
        :param list_id: Friend list ID.
        :param name: Name of the friend list.
        :param user_ids: IDs of users in the friend list.
        :param add_user_ids: (Applies if 'user_ids' parameter is not set.), User IDs to add to the friend list.
        :param delete_user_ids: (Applies if 'user_ids' parameter is not set.), User IDs to delete from the friend list.
        """
    
        method_parameters = {k: v for k, v in locals().items() if k not in {'self', 'raw_response'}}
        param_aliases = []
        method_name = 'friends.editList'
        response_type = responses.BaseOk
        return self._call(method_name, method_parameters, param_aliases, response_type)

    @overload
    def get(self, user_id: Optional[int] = None, order: Optional[str] = None, list_id: Optional[int] = None, count: Optional[int] = None, offset: Optional[int] = None, fields: None = None, name_case: Optional[str] = None, ref: Optional[str] = None) -> responses.FriendsGet: ...
    @overload
    def get(self, fields: List[Union[objects.UsersFields, str]], user_id: Optional[int] = None, order: Optional[str] = None, list_id: Optional[int] = None, count: Optional[int] = None, offset: Optional[int] = None, name_case: Optional[str] = None, ref: Optional[str] = None) -> responses.FriendsGetFields: ...
    def get(self, user_id: Optional[int] = None, order: Optional[str] = None, list_id: Optional[int] = None, count: Optional[int] = None, offset: Optional[int] = None, fields: Optional[List[Union[objects.UsersFields, str]]] = None, name_case: Optional[str] = None, ref: Optional[str] = None):
        """
        Returns a list of user IDs or detailed information about a user's friends.
        
        :param user_id: User ID. By default, the current user ID.
        :param order: Sort order: , 'name' — by name (enabled only if the 'fields' parameter is used), 'hints' — by rating, similar to how friends are sorted in My friends section, , This parameter is available only for [vk.com/dev/standalone|desktop applications].
        :param list_id: ID of the friend list returned by the [vk.com/dev/friends.getLists|friends.getLists] method to be used as the source. This parameter is taken into account only when the uid parameter is set to the current user ID. This parameter is available only for [vk.com/dev/standalone|desktop applications].
        :param count: Number of friends to return.
        :param offset: Offset needed to return a specific subset of friends.
        :param fields: Profile fields to return. Sample values: 'uid', 'first_name', 'last_name', 'nickname', 'sex', 'bdate' (birthdate), 'city', 'country', 'timezone', 'photo', 'photo_medium', 'photo_big', 'domain', 'has_mobile', 'rate', 'contacts', 'education'.
        :param name_case: Case for declension of user name and surname: , 'nom' — nominative (default) , 'gen' — genitive , 'dat' — dative , 'acc' — accusative , 'ins' — instrumental , 'abl' — prepositional
        :param ref:
        """
    
        method_parameters = {k: v for k, v in locals().items() if k not in {'self', 'raw_response'}}
        param_aliases = []
        method_name = 'friends.get'
        if not fields:
            response_type = responses.FriendsGet
        if fields:
            response_type = responses.FriendsGetFields
        return self._call(method_name, method_parameters, param_aliases, response_type)

    def get_app_users(self) -> responses.FriendsGetAppUsers:
        """
        Returns a list of IDs of the current user's friends who installed the application.
        """
    
        method_parameters = {k: v for k, v in locals().items() if k not in {'self', 'raw_response'}}
        param_aliases = []
        method_name = 'friends.getAppUsers'
        response_type = responses.FriendsGetAppUsers
        return self._call(method_name, method_parameters, param_aliases, response_type)

    def get_by_phones(self, phones: Optional[List[str]] = None, fields: Optional[List[Union[objects.UsersFields, str]]] = None) -> responses.FriendsGetByPhones:
        """
        Returns a list of the current user's friends whose phone numbers, validated or specified in a profile, are in a given list.
        
        :param phones: List of phone numbers in MSISDN format (maximum 1000). Example: "+79219876543,+79111234567"
        :param fields: Profile fields to return. Sample values: 'nickname', 'screen_name', 'sex', 'bdate' (birthdate), 'city', 'country', 'timezone', 'photo', 'photo_medium', 'photo_big', 'has_mobile', 'rate', 'contacts', 'education', 'online, counters'.
        """
    
        method_parameters = {k: v for k, v in locals().items() if k not in {'self', 'raw_response'}}
        param_aliases = []
        method_name = 'friends.getByPhones'
        response_type = responses.FriendsGetByPhones
        return self._call(method_name, method_parameters, param_aliases, response_type)

    def get_lists(self, user_id: Optional[int] = None, return_system: Optional[bool] = None) -> responses.FriendsGetLists:
        """
        Returns a list of the user's friend lists.
        
        :param user_id: User ID.
        :param return_system: '1' — to return system friend lists. By default: '0'.
        """
    
        method_parameters = {k: v for k, v in locals().items() if k not in {'self', 'raw_response'}}
        param_aliases = []
        method_name = 'friends.getLists'
        response_type = responses.FriendsGetLists
        return self._call(method_name, method_parameters, param_aliases, response_type)

    @overload
    def get_mutual(self, source_uid: Optional[int] = None, target_uid: Optional[int] = None, target_uids: None = None, order: Optional[str] = None, count: Optional[int] = None, offset: Optional[int] = None) -> responses.FriendsGetMutual: ...
    @overload
    def get_mutual(self, target_uids: List[int], source_uid: Optional[int] = None, target_uid: Optional[int] = None, order: Optional[str] = None, count: Optional[int] = None, offset: Optional[int] = None) -> responses.FriendsGetMutualTargetUids: ...
    def get_mutual(self, source_uid: Optional[int] = None, target_uid: Optional[int] = None, target_uids: Optional[List[int]] = None, order: Optional[str] = None, count: Optional[int] = None, offset: Optional[int] = None):
        """
        Returns a list of user IDs of the mutual friends of two users.
        
        :param source_uid: ID of the user whose friends will be checked against the friends of the user specified in 'target_uid'.
        :param target_uid: ID of the user whose friends will be checked against the friends of the user specified in 'source_uid'.
        :param target_uids: IDs of the users whose friends will be checked against the friends of the user specified in 'source_uid'.
        :param order: Sort order: 'random' — random order
        :param count: Number of mutual friends to return.
        :param offset: Offset needed to return a specific subset of mutual friends.
        """
    
        method_parameters = {k: v for k, v in locals().items() if k not in {'self', 'raw_response'}}
        param_aliases = []
        method_name = 'friends.getMutual'
        if not target_uids:
            response_type = responses.FriendsGetMutual
        if target_uids:
            response_type = responses.FriendsGetMutualTargetUids
        return self._call(method_name, method_parameters, param_aliases, response_type)

    @overload
    def get_online(self, user_id: Optional[int] = None, list_id: Optional[int] = None, online_mobile: None = None, order: Optional[str] = None, count: Optional[int] = None, offset: Optional[int] = None) -> responses.FriendsGetOnline: ...
    @overload
    def get_online(self, online_mobile: bool, user_id: Optional[int] = None, list_id: Optional[int] = None, order: Optional[str] = None, count: Optional[int] = None, offset: Optional[int] = None) -> responses.FriendsGetOnlineOnlineMobile: ...
    def get_online(self, user_id: Optional[int] = None, list_id: Optional[int] = None, online_mobile: Optional[bool] = None, order: Optional[str] = None, count: Optional[int] = None, offset: Optional[int] = None):
        """
        Returns a list of user IDs of a user's friends who are online.
        
        :param user_id: User ID.
        :param list_id: Friend list ID. If this parameter is not set, information about all online friends is returned.
        :param online_mobile: '1' — to return an additional 'online_mobile' field, '0' — (default),
        :param order: Sort order: 'random' — random order
        :param count: Number of friends to return.
        :param offset: Offset needed to return a specific subset of friends.
        """
    
        method_parameters = {k: v for k, v in locals().items() if k not in {'self', 'raw_response'}}
        param_aliases = []
        method_name = 'friends.getOnline'
        if not online_mobile:
            response_type = responses.FriendsGetOnline
        if online_mobile:
            response_type = responses.FriendsGetOnlineOnlineMobile
        return self._call(method_name, method_parameters, param_aliases, response_type)

    def get_recent(self, count: Optional[int] = None) -> responses.FriendsGetRecent:
        """
        Returns a list of user IDs of the current user's recently added friends.
        
        :param count: Number of recently added friends to return.
        """
    
        method_parameters = {k: v for k, v in locals().items() if k not in {'self', 'raw_response'}}
        param_aliases = []
        method_name = 'friends.getRecent'
        response_type = responses.FriendsGetRecent
        return self._call(method_name, method_parameters, param_aliases, response_type)

    @overload
    def get_requests(self, offset: Optional[int] = None, count: Optional[int] = None, extended: None = None, need_mutual: None = None, out: Optional[bool] = None, sort: Optional[int] = None, need_viewed: Optional[bool] = None, suggested: Optional[bool] = None, ref: Optional[str] = None, fields: Optional[List[Union[objects.UsersFields, str]]] = None) -> responses.FriendsGetRequests: ...
    @overload
    def get_requests(self, need_mutual: bool, offset: Optional[int] = None, count: Optional[int] = None, extended: None = None, out: Optional[bool] = None, sort: Optional[int] = None, need_viewed: Optional[bool] = None, suggested: Optional[bool] = None, ref: Optional[str] = None, fields: Optional[List[Union[objects.UsersFields, str]]] = None) -> responses.FriendsGetRequestsNeedMutual: ...
    @overload
    def get_requests(self, extended: bool, offset: Optional[int] = None, count: Optional[int] = None, need_mutual: None = None, out: Optional[bool] = None, sort: Optional[int] = None, need_viewed: Optional[bool] = None, suggested: Optional[bool] = None, ref: Optional[str] = None, fields: Optional[List[Union[objects.UsersFields, str]]] = None) -> responses.FriendsGetRequestsExtended: ...
    def get_requests(self, offset: Optional[int] = None, count: Optional[int] = None, extended: Optional[bool] = None, need_mutual: Optional[bool] = None, out: Optional[bool] = None, sort: Optional[int] = None, need_viewed: Optional[bool] = None, suggested: Optional[bool] = None, ref: Optional[str] = None, fields: Optional[List[Union[objects.UsersFields, str]]] = None):
        """
        Returns information about the current user's incoming and outgoing friend requests.
        
        :param offset: Offset needed to return a specific subset of friend requests.
        :param count: Number of friend requests to return (default 100, maximum 1000).
        :param extended: '1' — to return response messages from users who have sent a friend request or, if 'suggested' is set to '1', to return a list of suggested friends
        :param need_mutual: '1' — to return a list of mutual friends (up to 20), if any
        :param out: '1' — to return outgoing requests, '0' — to return incoming requests (default)
        :param sort: Sort order: '1' — by number of mutual friends, '0' — by date
        :param need_viewed:
        :param suggested: '1' — to return a list of suggested friends, '0' — to return friend requests (default)
        :param ref:
        :param fields:
        """
    
        method_parameters = {k: v for k, v in locals().items() if k not in {'self', 'raw_response'}}
        param_aliases = []
        method_name = 'friends.getRequests'
        if not need_mutual and not extended:
            response_type = responses.FriendsGetRequests
        if need_mutual and not extended:
            response_type = responses.FriendsGetRequestsNeedMutual
        if not need_mutual and extended:
            response_type = responses.FriendsGetRequestsExtended
        return self._call(method_name, method_parameters, param_aliases, response_type)

    def get_suggestions(self, filter_: Optional[List[str]] = None, count: Optional[int] = None, offset: Optional[int] = None, fields: Optional[List[Union[objects.UsersFields, str]]] = None, name_case: Optional[str] = None) -> responses.FriendsGetSuggestions:
        """
        Returns a list of profiles of users whom the current user may know.
        
        :param filter_: Types of potential friends to return: 'mutual' — users with many mutual friends , 'contacts' — users found with the [vk.com/dev/account.importContacts|account.importContacts] method , 'mutual_contacts' — users who imported the same contacts as the current user with the [vk.com/dev/account.importContacts|account.importContacts] method
        :param count: Number of suggestions to return.
        :param offset: Offset needed to return a specific subset of suggestions.
        :param fields: Profile fields to return. Sample values: 'nickname', 'screen_name', 'sex', 'bdate' (birthdate), 'city', 'country', 'timezone', 'photo', 'photo_medium', 'photo_big', 'has_mobile', 'rate', 'contacts', 'education', 'online', 'counters'.
        :param name_case: Case for declension of user name and surname: , 'nom' — nominative (default) , 'gen' — genitive , 'dat' — dative , 'acc' — accusative , 'ins' — instrumental , 'abl' — prepositional
        """
    
        method_parameters = {k: v for k, v in locals().items() if k not in {'self', 'raw_response'}}
        param_aliases = [('filter_', 'filter')]
        method_name = 'friends.getSuggestions'
        response_type = responses.FriendsGetSuggestions
        return self._call(method_name, method_parameters, param_aliases, response_type)

    def search(self, user_id: int, q: Optional[str] = None, fields: Optional[List[Union[objects.UsersFields, str]]] = None, name_case: Optional[str] = None, offset: Optional[int] = None, count: Optional[int] = None) -> responses.FriendsSearch:
        """
        Returns a list of friends matching the search criteria.
        
        :param user_id: User ID.
        :param q: Search query string (e.g., 'Vasya Babich').
        :param fields: Profile fields to return. Sample values: 'nickname', 'screen_name', 'sex', 'bdate' (birthdate), 'city', 'country', 'timezone', 'photo', 'photo_medium', 'photo_big', 'has_mobile', 'rate', 'contacts', 'education', 'online',
        :param name_case: Case for declension of user name and surname: 'nom' — nominative (default), 'gen' — genitive , 'dat' — dative, 'acc' — accusative , 'ins' — instrumental , 'abl' — prepositional
        :param offset: Offset needed to return a specific subset of friends.
        :param count: Number of friends to return.
        """
    
        method_parameters = {k: v for k, v in locals().items() if k not in {'self', 'raw_response'}}
        param_aliases = []
        method_name = 'friends.search'
        response_type = responses.FriendsSearch
        return self._call(method_name, method_parameters, param_aliases, response_type)
